# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetResourceGroupResult',
    'AwaitableGetResourceGroupResult',
    'get_resource_group',
    'get_resource_group_output',
]

@pulumi.output_type
class GetResourceGroupResult:
    """
    A collection of values returned by getResourceGroup.
    """
    def __init__(__self__, group_urn=None, created_at=None, id=None, name=None, owner=None, read_only=None, resources=None, updated_at=None):
        if group_urn and not isinstance(group_urn, str):
            raise TypeError("Expected argument 'group_urn' to be a str")
        pulumi.set(__self__, "group_urn", group_urn)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if read_only and not isinstance(read_only, bool):
            raise TypeError("Expected argument 'read_only' to be a bool")
        pulumi.set(__self__, "read_only", read_only)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="GroupURN")
    def group_urn(self) -> builtins.str:
        """
        URN of the resource group, used when writing policies
        """
        return pulumi.get(self, "group_urn")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        Date of the creation of the resource group
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the resource group
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def owner(self) -> builtins.str:
        """
        Name of the account owning the resource group
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> builtins.bool:
        """
        Marks that the resource group is not editable. Usually means that this is a default resource group created by OVHcloud
        """
        return pulumi.get(self, "read_only")

    @property
    @pulumi.getter
    def resources(self) -> Sequence[builtins.str]:
        """
        Set of the URNs of the resources contained in the resource group
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        Date of the last modification of the resource group
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetResourceGroupResult(GetResourceGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetResourceGroupResult(
            group_urn=self.group_urn,
            created_at=self.created_at,
            id=self.id,
            name=self.name,
            owner=self.owner,
            read_only=self.read_only,
            resources=self.resources,
            updated_at=self.updated_at)


def get_resource_group(id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetResourceGroupResult:
    """
    Use this data source get details about a resource group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_resource_group = ovh.Iam.get_resource_group(id="my_resource_group_id")
    ```


    :param builtins.str id: Id of the resource group
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Iam/getResourceGroup:getResourceGroup', __args__, opts=opts, typ=GetResourceGroupResult).value

    return AwaitableGetResourceGroupResult(
        group_urn=pulumi.get(__ret__, 'group_urn'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        owner=pulumi.get(__ret__, 'owner'),
        read_only=pulumi.get(__ret__, 'read_only'),
        resources=pulumi.get(__ret__, 'resources'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_resource_group_output(id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetResourceGroupResult]:
    """
    Use this data source get details about a resource group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_resource_group = ovh.Iam.get_resource_group(id="my_resource_group_id")
    ```


    :param builtins.str id: Id of the resource group
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Iam/getResourceGroup:getResourceGroup', __args__, opts=opts, typ=GetResourceGroupResult)
    return __ret__.apply(lambda __response__: GetResourceGroupResult(
        group_urn=pulumi.get(__response__, 'group_urn'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        owner=pulumi.get(__response__, 'owner'),
        read_only=pulumi.get(__response__, 'read_only'),
        resources=pulumi.get(__response__, 'resources'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IntegrationArgs', 'Integration']

@pulumi.input_type
class IntegrationArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 destination_service_id: pulumi.Input[builtins.str],
                 engine: pulumi.Input[builtins.str],
                 source_service_id: pulumi.Input[builtins.str],
                 parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Integration resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] destination_service_id: ID of the destination service.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). All engines available exept `mongodb`.
        :param pulumi.Input[builtins.str] source_service_id: ID of the source service.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] parameters: Parameters for the integration.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] type: Type of the integration. Available types:
               * `grafanaDashboard`
               * `grafanaDatasource`
               * `kafkaConnect`
               * `kafkaLogs`
               * `kafkaMirrorMaker`
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "destination_service_id", destination_service_id)
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "source_service_id", source_service_id)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="destinationServiceId")
    def destination_service_id(self) -> pulumi.Input[builtins.str]:
        """
        ID of the destination service.
        """
        return pulumi.get(self, "destination_service_id")

    @destination_service_id.setter
    def destination_service_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_service_id", value)

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Input[builtins.str]:
        """
        The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). All engines available exept `mongodb`.
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter(name="sourceServiceId")
    def source_service_id(self) -> pulumi.Input[builtins.str]:
        """
        ID of the source service.
        """
        return pulumi.get(self, "source_service_id")

    @source_service_id.setter
    def source_service_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "source_service_id", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Parameters for the integration.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of the integration. Available types:
        * `grafanaDashboard`
        * `grafanaDatasource`
        * `kafkaConnect`
        * `kafkaLogs`
        * `kafkaMirrorMaker`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _IntegrationState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 destination_service_id: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 source_service_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Integration resources.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] destination_service_id: ID of the destination service.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). All engines available exept `mongodb`.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] parameters: Parameters for the integration.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] source_service_id: ID of the source service.
        :param pulumi.Input[builtins.str] status: Current status of the integration.
        :param pulumi.Input[builtins.str] type: Type of the integration. Available types:
               * `grafanaDashboard`
               * `grafanaDatasource`
               * `kafkaConnect`
               * `kafkaLogs`
               * `kafkaMirrorMaker`
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if destination_service_id is not None:
            pulumi.set(__self__, "destination_service_id", destination_service_id)
        if engine is not None:
            pulumi.set(__self__, "engine", engine)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if source_service_id is not None:
            pulumi.set(__self__, "source_service_id", source_service_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="destinationServiceId")
    def destination_service_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the destination service.
        """
        return pulumi.get(self, "destination_service_id")

    @destination_service_id.setter
    def destination_service_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_service_id", value)

    @property
    @pulumi.getter
    def engine(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). All engines available exept `mongodb`.
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Parameters for the integration.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="sourceServiceId")
    def source_service_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the source service.
        """
        return pulumi.get(self, "source_service_id")

    @source_service_id.setter
    def source_service_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_service_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current status of the integration.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of the integration. Available types:
        * `grafanaDashboard`
        * `grafanaDatasource`
        * `kafkaConnect`
        * `kafkaLogs`
        * `kafkaMirrorMaker`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("ovh:CloudProjectDatabase/integration:Integration")
class Integration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 destination_service_id: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 source_service_id: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates an integration for a database cluster associated with a public cloud project.

        With this resource you can create an integration for all engine exept `mongodb`.

        Please take a look at the list of available `types` in the `Argument references` section in order to know the list of avaulable integrations. For example, thanks to the integration feature you can have your PostgreSQL logs in your OpenSearch Database.

        ## Example Usage

        Push PostgreSQL logs in an OpenSearch DB:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        db_postgresql = ovh.CloudProjectDatabase.get_database(service_name="XXXX",
            engine="postgresql",
            id="ZZZZ")
        db_opensearch = ovh.CloudProjectDatabase.get_database(service_name="XXXX",
            engine="opensearch",
            id="ZZZZ")
        integration = ovh.cloud_project_database.Integration("integration",
            service_name=db_postgresql.service_name,
            engine=db_postgresql.engine,
            cluster_id=db_postgresql.id,
            source_service_id=db_postgresql.id,
            destination_service_id=db_opensearch.id,
            type="opensearchLogs")
        ```

        ## Import

        OVHcloud Managed database clusters users can be imported using the `service_name`, `engine`, `cluster_id` and `id` of the user, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/integration:Integration my_user service_name/engine/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] destination_service_id: ID of the destination service.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). All engines available exept `mongodb`.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] parameters: Parameters for the integration.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] source_service_id: ID of the source service.
        :param pulumi.Input[builtins.str] type: Type of the integration. Available types:
               * `grafanaDashboard`
               * `grafanaDatasource`
               * `kafkaConnect`
               * `kafkaLogs`
               * `kafkaMirrorMaker`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IntegrationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an integration for a database cluster associated with a public cloud project.

        With this resource you can create an integration for all engine exept `mongodb`.

        Please take a look at the list of available `types` in the `Argument references` section in order to know the list of avaulable integrations. For example, thanks to the integration feature you can have your PostgreSQL logs in your OpenSearch Database.

        ## Example Usage

        Push PostgreSQL logs in an OpenSearch DB:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        db_postgresql = ovh.CloudProjectDatabase.get_database(service_name="XXXX",
            engine="postgresql",
            id="ZZZZ")
        db_opensearch = ovh.CloudProjectDatabase.get_database(service_name="XXXX",
            engine="opensearch",
            id="ZZZZ")
        integration = ovh.cloud_project_database.Integration("integration",
            service_name=db_postgresql.service_name,
            engine=db_postgresql.engine,
            cluster_id=db_postgresql.id,
            source_service_id=db_postgresql.id,
            destination_service_id=db_opensearch.id,
            type="opensearchLogs")
        ```

        ## Import

        OVHcloud Managed database clusters users can be imported using the `service_name`, `engine`, `cluster_id` and `id` of the user, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/integration:Integration my_user service_name/engine/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param IntegrationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IntegrationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 destination_service_id: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 source_service_id: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IntegrationArgs.__new__(IntegrationArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            if destination_service_id is None and not opts.urn:
                raise TypeError("Missing required property 'destination_service_id'")
            __props__.__dict__["destination_service_id"] = destination_service_id
            if engine is None and not opts.urn:
                raise TypeError("Missing required property 'engine'")
            __props__.__dict__["engine"] = engine
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["service_name"] = service_name
            if source_service_id is None and not opts.urn:
                raise TypeError("Missing required property 'source_service_id'")
            __props__.__dict__["source_service_id"] = source_service_id
            __props__.__dict__["type"] = type
            __props__.__dict__["status"] = None
        super(Integration, __self__).__init__(
            'ovh:CloudProjectDatabase/integration:Integration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            destination_service_id: Optional[pulumi.Input[builtins.str]] = None,
            engine: Optional[pulumi.Input[builtins.str]] = None,
            parameters: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            source_service_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'Integration':
        """
        Get an existing Integration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] destination_service_id: ID of the destination service.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). All engines available exept `mongodb`.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] parameters: Parameters for the integration.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] source_service_id: ID of the source service.
        :param pulumi.Input[builtins.str] status: Current status of the integration.
        :param pulumi.Input[builtins.str] type: Type of the integration. Available types:
               * `grafanaDashboard`
               * `grafanaDatasource`
               * `kafkaConnect`
               * `kafkaLogs`
               * `kafkaMirrorMaker`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IntegrationState.__new__(_IntegrationState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["destination_service_id"] = destination_service_id
        __props__.__dict__["engine"] = engine
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["source_service_id"] = source_service_id
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return Integration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="destinationServiceId")
    def destination_service_id(self) -> pulumi.Output[builtins.str]:
        """
        ID of the destination service.
        """
        return pulumi.get(self, "destination_service_id")

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Output[builtins.str]:
        """
        The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). All engines available exept `mongodb`.
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Parameters for the integration.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="sourceServiceId")
    def source_service_id(self) -> pulumi.Output[builtins.str]:
        """
        ID of the source service.
        """
        return pulumi.get(self, "source_service_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Current status of the integration.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Type of the integration. Available types:
        * `grafanaDashboard`
        * `grafanaDatasource`
        * `kafkaConnect`
        * `kafkaLogs`
        * `kafkaMirrorMaker`
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .apio_auth2_client import *
from .get_apio_auth2_client import *
from .get_apio_auth2_clients import *
from .get_identity_group import *
from .get_identity_groups import *
from .get_identity_user import *
from .get_identity_users import *
from .get_me import *
from .get_paymentmean_bank_account import *
from .get_paymentmean_credit_card import *
from .identity_group import *
from .identity_user import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .cloud_project import *
from .dedicated_cloud_datacenter import *
from .dedicated_server import *
from .dedicated_server_interface import *
from .get_vracks import *
from .ip_address import *
from .ip_loadbalancing import *
from .ip_v6 import *
from .ov_hcloud_connect import *
from .vrack import *
from .vrack_dedicated_cloud import *
from .vrackservices import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatabaseArgs', 'Database']

@pulumi.input_type
class DatabaseArgs:
    def __init__(__self__, *,
                 engine: pulumi.Input[builtins.str],
                 flavor: pulumi.Input[builtins.str],
                 nodes: pulumi.Input[Sequence[pulumi.Input['DatabaseNodeArgs']]],
                 plan: pulumi.Input[builtins.str],
                 version: pulumi.Input[builtins.str],
                 advanced_configuration: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 backup_regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 backup_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disk_size: Optional[pulumi.Input[builtins.int]] = None,
                 ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseIpRestrictionArgs']]]] = None,
                 kafka_rest_api: Optional[pulumi.Input[builtins.bool]] = None,
                 kafka_schema_registry: Optional[pulumi.Input[builtins.bool]] = None,
                 maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
                 opensearch_acls_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Database resource.
        :param pulumi.Input[builtins.str] engine: The database engine you want to deploy. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] flavor: A valid OVHcloud public cloud database flavor name in which the nodes will be started. Ex: "db1-7". Changing this value upgrade the nodes with the new flavor. You can find the list of flavor names: https://www.ovhcloud.com/fr/public-cloud/prices/
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseNodeArgs']]] nodes: List of nodes object. Multi region cluster are not yet available, all node should be identical.
        :param pulumi.Input[builtins.str] plan: Plan of the cluster.
               * MongoDB: Enum: "discovery", "production", "advanced".
               * Mysql, PosgreSQL, Cassandra, M3DB, : Enum: "essential", "business", "enterprise".
               * M3 Aggregator: "business", "enterprise".
               * Redis: "essential", "business".
               * Valkey: "essential", "business".
        :param pulumi.Input[builtins.str] version: The version of the engine in which the service should be deployed
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] advanced_configuration: Advanced configuration key / value.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] backup_regions: List of region where backups are pushed. Not more than 1 regions for MongoDB. Not more than 2 regions for the other engines with one being the same as the nodes[].region field
        :param pulumi.Input[builtins.str] backup_time: Time on which backups start every day (this parameter is not usable on the following engines: "m3db", "grafana", "kafka", "kafkaconnect", "kafkamirrormaker", "opensearch", "m3aggregator").
        :param pulumi.Input[builtins.str] description: Small description of the database service.
        :param pulumi.Input[builtins.int] disk_size: The disk size (in GB) of the database service.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseIpRestrictionArgs']]] ip_restrictions: IP Blocks authorized to access to the cluster.
        :param pulumi.Input[builtins.bool] kafka_rest_api: Defines whether the REST API is enabled on a kafka cluster
        :param pulumi.Input[builtins.bool] kafka_schema_registry: Defines whether the schema registry is enabled on a Kafka cluster
        :param pulumi.Input[builtins.str] maintenance_time: Time on which maintenances can start every day.
        :param pulumi.Input[builtins.bool] opensearch_acls_enabled: Defines whether the ACLs are enabled on an OpenSearch cluster
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "flavor", flavor)
        pulumi.set(__self__, "nodes", nodes)
        pulumi.set(__self__, "plan", plan)
        pulumi.set(__self__, "version", version)
        if advanced_configuration is not None:
            pulumi.set(__self__, "advanced_configuration", advanced_configuration)
        if backup_regions is not None:
            pulumi.set(__self__, "backup_regions", backup_regions)
        if backup_time is not None:
            pulumi.set(__self__, "backup_time", backup_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disk_size is not None:
            pulumi.set(__self__, "disk_size", disk_size)
        if ip_restrictions is not None:
            pulumi.set(__self__, "ip_restrictions", ip_restrictions)
        if kafka_rest_api is not None:
            pulumi.set(__self__, "kafka_rest_api", kafka_rest_api)
        if kafka_schema_registry is not None:
            pulumi.set(__self__, "kafka_schema_registry", kafka_schema_registry)
        if maintenance_time is not None:
            pulumi.set(__self__, "maintenance_time", maintenance_time)
        if opensearch_acls_enabled is not None:
            pulumi.set(__self__, "opensearch_acls_enabled", opensearch_acls_enabled)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Input[builtins.str]:
        """
        The database engine you want to deploy. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def flavor(self) -> pulumi.Input[builtins.str]:
        """
        A valid OVHcloud public cloud database flavor name in which the nodes will be started. Ex: "db1-7". Changing this value upgrade the nodes with the new flavor. You can find the list of flavor names: https://www.ovhcloud.com/fr/public-cloud/prices/
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "flavor", value)

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Input[Sequence[pulumi.Input['DatabaseNodeArgs']]]:
        """
        List of nodes object. Multi region cluster are not yet available, all node should be identical.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: pulumi.Input[Sequence[pulumi.Input['DatabaseNodeArgs']]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Input[builtins.str]:
        """
        Plan of the cluster.
        * MongoDB: Enum: "discovery", "production", "advanced".
        * Mysql, PosgreSQL, Cassandra, M3DB, : Enum: "essential", "business", "enterprise".
        * M3 Aggregator: "business", "enterprise".
        * Redis: "essential", "business".
        * Valkey: "essential", "business".
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter
    def version(self) -> pulumi.Input[builtins.str]:
        """
        The version of the engine in which the service should be deployed
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="advancedConfiguration")
    def advanced_configuration(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Advanced configuration key / value.
        """
        return pulumi.get(self, "advanced_configuration")

    @advanced_configuration.setter
    def advanced_configuration(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "advanced_configuration", value)

    @property
    @pulumi.getter(name="backupRegions")
    def backup_regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of region where backups are pushed. Not more than 1 regions for MongoDB. Not more than 2 regions for the other engines with one being the same as the nodes[].region field
        """
        return pulumi.get(self, "backup_regions")

    @backup_regions.setter
    def backup_regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "backup_regions", value)

    @property
    @pulumi.getter(name="backupTime")
    def backup_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time on which backups start every day (this parameter is not usable on the following engines: "m3db", "grafana", "kafka", "kafkaconnect", "kafkamirrormaker", "opensearch", "m3aggregator").
        """
        return pulumi.get(self, "backup_time")

    @backup_time.setter
    def backup_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Small description of the database service.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The disk size (in GB) of the database service.
        """
        return pulumi.get(self, "disk_size")

    @disk_size.setter
    def disk_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "disk_size", value)

    @property
    @pulumi.getter(name="ipRestrictions")
    def ip_restrictions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseIpRestrictionArgs']]]]:
        """
        IP Blocks authorized to access to the cluster.
        """
        return pulumi.get(self, "ip_restrictions")

    @ip_restrictions.setter
    def ip_restrictions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseIpRestrictionArgs']]]]):
        pulumi.set(self, "ip_restrictions", value)

    @property
    @pulumi.getter(name="kafkaRestApi")
    def kafka_rest_api(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the REST API is enabled on a kafka cluster
        """
        return pulumi.get(self, "kafka_rest_api")

    @kafka_rest_api.setter
    def kafka_rest_api(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "kafka_rest_api", value)

    @property
    @pulumi.getter(name="kafkaSchemaRegistry")
    def kafka_schema_registry(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the schema registry is enabled on a Kafka cluster
        """
        return pulumi.get(self, "kafka_schema_registry")

    @kafka_schema_registry.setter
    def kafka_schema_registry(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "kafka_schema_registry", value)

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time on which maintenances can start every day.
        """
        return pulumi.get(self, "maintenance_time")

    @maintenance_time.setter
    def maintenance_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "maintenance_time", value)

    @property
    @pulumi.getter(name="opensearchAclsEnabled")
    def opensearch_acls_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the ACLs are enabled on an OpenSearch cluster
        """
        return pulumi.get(self, "opensearch_acls_enabled")

    @opensearch_acls_enabled.setter
    def opensearch_acls_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "opensearch_acls_enabled", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _DatabaseState:
    def __init__(__self__, *,
                 advanced_configuration: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 backup_regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 backup_time: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disk_size: Optional[pulumi.Input[builtins.int]] = None,
                 disk_type: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseEndpointArgs']]]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 flavor: Optional[pulumi.Input[builtins.str]] = None,
                 ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseIpRestrictionArgs']]]] = None,
                 kafka_rest_api: Optional[pulumi.Input[builtins.bool]] = None,
                 kafka_schema_registry: Optional[pulumi.Input[builtins.bool]] = None,
                 maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseNodeArgs']]]] = None,
                 opensearch_acls_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 plan: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Database resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] advanced_configuration: Advanced configuration key / value.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] backup_regions: List of region where backups are pushed. Not more than 1 regions for MongoDB. Not more than 2 regions for the other engines with one being the same as the nodes[].region field
        :param pulumi.Input[builtins.str] backup_time: Time on which backups start every day (this parameter is not usable on the following engines: "m3db", "grafana", "kafka", "kafkaconnect", "kafkamirrormaker", "opensearch", "m3aggregator").
        :param pulumi.Input[builtins.str] created_at: Date of the creation of the cluster.
        :param pulumi.Input[builtins.str] description: Small description of the database service.
        :param pulumi.Input[builtins.int] disk_size: The disk size (in GB) of the database service.
        :param pulumi.Input[builtins.str] disk_type: Defines the disk type of the database service.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseEndpointArgs']]] endpoints: List of all endpoints objects of the service.
        :param pulumi.Input[builtins.str] engine: The database engine you want to deploy. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] flavor: A valid OVHcloud public cloud database flavor name in which the nodes will be started. Ex: "db1-7". Changing this value upgrade the nodes with the new flavor. You can find the list of flavor names: https://www.ovhcloud.com/fr/public-cloud/prices/
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseIpRestrictionArgs']]] ip_restrictions: IP Blocks authorized to access to the cluster.
        :param pulumi.Input[builtins.bool] kafka_rest_api: Defines whether the REST API is enabled on a kafka cluster
        :param pulumi.Input[builtins.bool] kafka_schema_registry: Defines whether the schema registry is enabled on a Kafka cluster
        :param pulumi.Input[builtins.str] maintenance_time: Time on which maintenances can start every day.
        :param pulumi.Input[builtins.str] network_type: Type of network of the cluster.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseNodeArgs']]] nodes: List of nodes object. Multi region cluster are not yet available, all node should be identical.
        :param pulumi.Input[builtins.bool] opensearch_acls_enabled: Defines whether the ACLs are enabled on an OpenSearch cluster
        :param pulumi.Input[builtins.str] plan: Plan of the cluster.
               * MongoDB: Enum: "discovery", "production", "advanced".
               * Mysql, PosgreSQL, Cassandra, M3DB, : Enum: "essential", "business", "enterprise".
               * M3 Aggregator: "business", "enterprise".
               * Redis: "essential", "business".
               * Valkey: "essential", "business".
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: Current status of the cluster.
        :param pulumi.Input[builtins.str] version: The version of the engine in which the service should be deployed
        """
        if advanced_configuration is not None:
            pulumi.set(__self__, "advanced_configuration", advanced_configuration)
        if backup_regions is not None:
            pulumi.set(__self__, "backup_regions", backup_regions)
        if backup_time is not None:
            pulumi.set(__self__, "backup_time", backup_time)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disk_size is not None:
            pulumi.set(__self__, "disk_size", disk_size)
        if disk_type is not None:
            pulumi.set(__self__, "disk_type", disk_type)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if engine is not None:
            pulumi.set(__self__, "engine", engine)
        if flavor is not None:
            pulumi.set(__self__, "flavor", flavor)
        if ip_restrictions is not None:
            pulumi.set(__self__, "ip_restrictions", ip_restrictions)
        if kafka_rest_api is not None:
            pulumi.set(__self__, "kafka_rest_api", kafka_rest_api)
        if kafka_schema_registry is not None:
            pulumi.set(__self__, "kafka_schema_registry", kafka_schema_registry)
        if maintenance_time is not None:
            pulumi.set(__self__, "maintenance_time", maintenance_time)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if opensearch_acls_enabled is not None:
            pulumi.set(__self__, "opensearch_acls_enabled", opensearch_acls_enabled)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="advancedConfiguration")
    def advanced_configuration(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Advanced configuration key / value.
        """
        return pulumi.get(self, "advanced_configuration")

    @advanced_configuration.setter
    def advanced_configuration(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "advanced_configuration", value)

    @property
    @pulumi.getter(name="backupRegions")
    def backup_regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of region where backups are pushed. Not more than 1 regions for MongoDB. Not more than 2 regions for the other engines with one being the same as the nodes[].region field
        """
        return pulumi.get(self, "backup_regions")

    @backup_regions.setter
    def backup_regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "backup_regions", value)

    @property
    @pulumi.getter(name="backupTime")
    def backup_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time on which backups start every day (this parameter is not usable on the following engines: "m3db", "grafana", "kafka", "kafkaconnect", "kafkamirrormaker", "opensearch", "m3aggregator").
        """
        return pulumi.get(self, "backup_time")

    @backup_time.setter
    def backup_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_time", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the creation of the cluster.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Small description of the database service.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The disk size (in GB) of the database service.
        """
        return pulumi.get(self, "disk_size")

    @disk_size.setter
    def disk_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "disk_size", value)

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Defines the disk type of the database service.
        """
        return pulumi.get(self, "disk_type")

    @disk_type.setter
    def disk_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disk_type", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseEndpointArgs']]]]:
        """
        List of all endpoints objects of the service.
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseEndpointArgs']]]]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter
    def engine(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The database engine you want to deploy. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def flavor(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A valid OVHcloud public cloud database flavor name in which the nodes will be started. Ex: "db1-7". Changing this value upgrade the nodes with the new flavor. You can find the list of flavor names: https://www.ovhcloud.com/fr/public-cloud/prices/
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flavor", value)

    @property
    @pulumi.getter(name="ipRestrictions")
    def ip_restrictions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseIpRestrictionArgs']]]]:
        """
        IP Blocks authorized to access to the cluster.
        """
        return pulumi.get(self, "ip_restrictions")

    @ip_restrictions.setter
    def ip_restrictions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseIpRestrictionArgs']]]]):
        pulumi.set(self, "ip_restrictions", value)

    @property
    @pulumi.getter(name="kafkaRestApi")
    def kafka_rest_api(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the REST API is enabled on a kafka cluster
        """
        return pulumi.get(self, "kafka_rest_api")

    @kafka_rest_api.setter
    def kafka_rest_api(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "kafka_rest_api", value)

    @property
    @pulumi.getter(name="kafkaSchemaRegistry")
    def kafka_schema_registry(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the schema registry is enabled on a Kafka cluster
        """
        return pulumi.get(self, "kafka_schema_registry")

    @kafka_schema_registry.setter
    def kafka_schema_registry(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "kafka_schema_registry", value)

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time on which maintenances can start every day.
        """
        return pulumi.get(self, "maintenance_time")

    @maintenance_time.setter
    def maintenance_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "maintenance_time", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of network of the cluster.
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseNodeArgs']]]]:
        """
        List of nodes object. Multi region cluster are not yet available, all node should be identical.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseNodeArgs']]]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="opensearchAclsEnabled")
    def opensearch_acls_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the ACLs are enabled on an OpenSearch cluster
        """
        return pulumi.get(self, "opensearch_acls_enabled")

    @opensearch_acls_enabled.setter
    def opensearch_acls_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "opensearch_acls_enabled", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Plan of the cluster.
        * MongoDB: Enum: "discovery", "production", "advanced".
        * Mysql, PosgreSQL, Cassandra, M3DB, : Enum: "essential", "business", "enterprise".
        * M3 Aggregator: "business", "enterprise".
        * Redis: "essential", "business".
        * Valkey: "essential", "business".
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current status of the cluster.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The version of the engine in which the service should be deployed
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.type_token("ovh:CloudProject/database:Database")
class Database(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advanced_configuration: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 backup_regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 backup_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disk_size: Optional[pulumi.Input[builtins.int]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 flavor: Optional[pulumi.Input[builtins.str]] = None,
                 ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseIpRestrictionArgs', 'DatabaseIpRestrictionArgsDict']]]]] = None,
                 kafka_rest_api: Optional[pulumi.Input[builtins.bool]] = None,
                 kafka_schema_registry: Optional[pulumi.Input[builtins.bool]] = None,
                 maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseNodeArgs', 'DatabaseNodeArgsDict']]]]] = None,
                 opensearch_acls_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 plan: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        Minimum settings for each engine (region choice is up to the user):

        ```python
        import pulumi
        import pulumi_ovh as ovh

        cassandradb = ovh.cloud_project.Database("cassandradb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-cassandra",
            engine="cassandra",
            version="4.0",
            plan="essential",
            nodes=[
                {
                    "region": "BHS",
                },
                {
                    "region": "BHS",
                },
                {
                    "region": "BHS",
                },
            ],
            flavor="db1-4")
        kafkadb = ovh.cloud_project.Database("kafkadb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-kafka",
            engine="kafka",
            version="3.8",
            flavor="db1-4",
            plan="business",
            kafka_rest_api=True,
            kafka_schema_registry=True,
            nodes=[
                {
                    "region": "DE",
                },
                {
                    "region": "DE",
                },
                {
                    "region": "DE",
                },
            ])
        m3db = ovh.cloud_project.Database("m3db",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-m3db",
            engine="m3db",
            version="1.2",
            plan="essential",
            nodes=[{
                "region": "BHS",
            }],
            flavor="db1-7")
        mongodb = ovh.cloud_project.Database("mongodb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-mongodb",
            engine="mongodb",
            version="5.0",
            plan="discovery",
            nodes=[{
                "region": "GRA",
            }],
            flavor="db1-2")
        mysqldb = ovh.cloud_project.Database("mysqldb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-mysql",
            engine="mysql",
            version="8",
            plan="essential",
            nodes=[{
                "region": "SBG",
            }],
            flavor="db1-4",
            advanced_configuration={
                "mysql.sql_mode": "ANSI,ERROR_FOR_DIVISION_BY_ZERO,NO_ENGINE_SUBSTITUTION,NO_ZERO_DATE,NO_ZERO_IN_DATE,STRICT_ALL_TABLES",
                "mysql.sql_require_primary_key": "true",
            })
        opensearchdb = ovh.cloud_project.Database("opensearchdb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-opensearch",
            engine="opensearch",
            version="1",
            plan="essential",
            opensearch_acls_enabled=True,
            nodes=[{
                "region": "UK",
            }],
            flavor="db1-4")
        pgsqldb = ovh.cloud_project.Database("pgsqldb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-postgresql",
            engine="postgresql",
            version="14",
            plan="essential",
            nodes=[{
                "region": "WAW",
            }],
            flavor="db1-4",
            ip_restrictions=[
                {
                    "description": "ip 1",
                    "ip": "178.97.6.0/24",
                },
                {
                    "description": "ip 2",
                    "ip": "178.97.7.0/24",
                },
            ])
        redisdb = ovh.cloud_project.Database("redisdb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-redis",
            engine="redis",
            version="6.2",
            plan="essential",
            nodes=[{
                "region": "BHS",
            }],
            flavor="db1-4")
        grafana = ovh.cloud_project.Database("grafana",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-grafana",
            engine="grafana",
            version="9.1",
            plan="essential",
            nodes=[{
                "region": "GRA",
            }],
            flavor="db1-4")
        valkeydb = ovh.cloud_project.Database("valkeydb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-valkey",
            engine="valkey",
            version="8.0",
            plan="essential",
            nodes=[{
                "region": "BHS",
            }],
            flavor="db1-4")
        ```

        To deploy a business PostgreSQL service with two nodes on public network:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        postgresql = ovh.cloud_project.Database("postgresql",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-postgresql",
            engine="postgresql",
            version="14",
            plan="business",
            nodes=[
                {
                    "region": "GRA",
                },
                {
                    "region": "GRA",
                },
            ],
            flavor="db1-15")
        ```

        To deploy an enterprise MongoDB service with three nodes on private network:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        mongodb = ovh.cloud_project.Database("mongodb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-mongodb",
            engine="mongodb",
            version="5.0",
            plan="production",
            nodes=[
                {
                    "region": "SBG",
                    "subnet_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                    "network_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                },
                {
                    "region": "SBG",
                    "subnet_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                    "network_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                },
                {
                    "region": "SBG",
                    "subnet_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                    "network_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                },
            ],
            flavor="db1-30")
        ```

        ## Import

        OVHcloud Managed database clusters can be imported using the `service_name`, `engine`, `id` of the cluster, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/database:Database my_database_cluster service_name/engine/id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] advanced_configuration: Advanced configuration key / value.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] backup_regions: List of region where backups are pushed. Not more than 1 regions for MongoDB. Not more than 2 regions for the other engines with one being the same as the nodes[].region field
        :param pulumi.Input[builtins.str] backup_time: Time on which backups start every day (this parameter is not usable on the following engines: "m3db", "grafana", "kafka", "kafkaconnect", "kafkamirrormaker", "opensearch", "m3aggregator").
        :param pulumi.Input[builtins.str] description: Small description of the database service.
        :param pulumi.Input[builtins.int] disk_size: The disk size (in GB) of the database service.
        :param pulumi.Input[builtins.str] engine: The database engine you want to deploy. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] flavor: A valid OVHcloud public cloud database flavor name in which the nodes will be started. Ex: "db1-7". Changing this value upgrade the nodes with the new flavor. You can find the list of flavor names: https://www.ovhcloud.com/fr/public-cloud/prices/
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseIpRestrictionArgs', 'DatabaseIpRestrictionArgsDict']]]] ip_restrictions: IP Blocks authorized to access to the cluster.
        :param pulumi.Input[builtins.bool] kafka_rest_api: Defines whether the REST API is enabled on a kafka cluster
        :param pulumi.Input[builtins.bool] kafka_schema_registry: Defines whether the schema registry is enabled on a Kafka cluster
        :param pulumi.Input[builtins.str] maintenance_time: Time on which maintenances can start every day.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseNodeArgs', 'DatabaseNodeArgsDict']]]] nodes: List of nodes object. Multi region cluster are not yet available, all node should be identical.
        :param pulumi.Input[builtins.bool] opensearch_acls_enabled: Defines whether the ACLs are enabled on an OpenSearch cluster
        :param pulumi.Input[builtins.str] plan: Plan of the cluster.
               * MongoDB: Enum: "discovery", "production", "advanced".
               * Mysql, PosgreSQL, Cassandra, M3DB, : Enum: "essential", "business", "enterprise".
               * M3 Aggregator: "business", "enterprise".
               * Redis: "essential", "business".
               * Valkey: "essential", "business".
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] version: The version of the engine in which the service should be deployed
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        Minimum settings for each engine (region choice is up to the user):

        ```python
        import pulumi
        import pulumi_ovh as ovh

        cassandradb = ovh.cloud_project.Database("cassandradb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-cassandra",
            engine="cassandra",
            version="4.0",
            plan="essential",
            nodes=[
                {
                    "region": "BHS",
                },
                {
                    "region": "BHS",
                },
                {
                    "region": "BHS",
                },
            ],
            flavor="db1-4")
        kafkadb = ovh.cloud_project.Database("kafkadb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-kafka",
            engine="kafka",
            version="3.8",
            flavor="db1-4",
            plan="business",
            kafka_rest_api=True,
            kafka_schema_registry=True,
            nodes=[
                {
                    "region": "DE",
                },
                {
                    "region": "DE",
                },
                {
                    "region": "DE",
                },
            ])
        m3db = ovh.cloud_project.Database("m3db",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-m3db",
            engine="m3db",
            version="1.2",
            plan="essential",
            nodes=[{
                "region": "BHS",
            }],
            flavor="db1-7")
        mongodb = ovh.cloud_project.Database("mongodb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-mongodb",
            engine="mongodb",
            version="5.0",
            plan="discovery",
            nodes=[{
                "region": "GRA",
            }],
            flavor="db1-2")
        mysqldb = ovh.cloud_project.Database("mysqldb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-mysql",
            engine="mysql",
            version="8",
            plan="essential",
            nodes=[{
                "region": "SBG",
            }],
            flavor="db1-4",
            advanced_configuration={
                "mysql.sql_mode": "ANSI,ERROR_FOR_DIVISION_BY_ZERO,NO_ENGINE_SUBSTITUTION,NO_ZERO_DATE,NO_ZERO_IN_DATE,STRICT_ALL_TABLES",
                "mysql.sql_require_primary_key": "true",
            })
        opensearchdb = ovh.cloud_project.Database("opensearchdb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-opensearch",
            engine="opensearch",
            version="1",
            plan="essential",
            opensearch_acls_enabled=True,
            nodes=[{
                "region": "UK",
            }],
            flavor="db1-4")
        pgsqldb = ovh.cloud_project.Database("pgsqldb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-postgresql",
            engine="postgresql",
            version="14",
            plan="essential",
            nodes=[{
                "region": "WAW",
            }],
            flavor="db1-4",
            ip_restrictions=[
                {
                    "description": "ip 1",
                    "ip": "178.97.6.0/24",
                },
                {
                    "description": "ip 2",
                    "ip": "178.97.7.0/24",
                },
            ])
        redisdb = ovh.cloud_project.Database("redisdb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-redis",
            engine="redis",
            version="6.2",
            plan="essential",
            nodes=[{
                "region": "BHS",
            }],
            flavor="db1-4")
        grafana = ovh.cloud_project.Database("grafana",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-grafana",
            engine="grafana",
            version="9.1",
            plan="essential",
            nodes=[{
                "region": "GRA",
            }],
            flavor="db1-4")
        valkeydb = ovh.cloud_project.Database("valkeydb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-valkey",
            engine="valkey",
            version="8.0",
            plan="essential",
            nodes=[{
                "region": "BHS",
            }],
            flavor="db1-4")
        ```

        To deploy a business PostgreSQL service with two nodes on public network:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        postgresql = ovh.cloud_project.Database("postgresql",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-postgresql",
            engine="postgresql",
            version="14",
            plan="business",
            nodes=[
                {
                    "region": "GRA",
                },
                {
                    "region": "GRA",
                },
            ],
            flavor="db1-15")
        ```

        To deploy an enterprise MongoDB service with three nodes on private network:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        mongodb = ovh.cloud_project.Database("mongodb",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            description="my-first-mongodb",
            engine="mongodb",
            version="5.0",
            plan="production",
            nodes=[
                {
                    "region": "SBG",
                    "subnet_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                    "network_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                },
                {
                    "region": "SBG",
                    "subnet_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                    "network_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                },
                {
                    "region": "SBG",
                    "subnet_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                    "network_id": "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX",
                },
            ],
            flavor="db1-30")
        ```

        ## Import

        OVHcloud Managed database clusters can be imported using the `service_name`, `engine`, `id` of the cluster, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/database:Database my_database_cluster service_name/engine/id
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advanced_configuration: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 backup_regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 backup_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disk_size: Optional[pulumi.Input[builtins.int]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 flavor: Optional[pulumi.Input[builtins.str]] = None,
                 ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseIpRestrictionArgs', 'DatabaseIpRestrictionArgsDict']]]]] = None,
                 kafka_rest_api: Optional[pulumi.Input[builtins.bool]] = None,
                 kafka_schema_registry: Optional[pulumi.Input[builtins.bool]] = None,
                 maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseNodeArgs', 'DatabaseNodeArgsDict']]]]] = None,
                 opensearch_acls_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 plan: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseArgs.__new__(DatabaseArgs)

            __props__.__dict__["advanced_configuration"] = advanced_configuration
            __props__.__dict__["backup_regions"] = backup_regions
            __props__.__dict__["backup_time"] = backup_time
            __props__.__dict__["description"] = description
            __props__.__dict__["disk_size"] = disk_size
            if engine is None and not opts.urn:
                raise TypeError("Missing required property 'engine'")
            __props__.__dict__["engine"] = engine
            if flavor is None and not opts.urn:
                raise TypeError("Missing required property 'flavor'")
            __props__.__dict__["flavor"] = flavor
            __props__.__dict__["ip_restrictions"] = ip_restrictions
            __props__.__dict__["kafka_rest_api"] = kafka_rest_api
            __props__.__dict__["kafka_schema_registry"] = kafka_schema_registry
            __props__.__dict__["maintenance_time"] = maintenance_time
            if nodes is None and not opts.urn:
                raise TypeError("Missing required property 'nodes'")
            __props__.__dict__["nodes"] = nodes
            __props__.__dict__["opensearch_acls_enabled"] = opensearch_acls_enabled
            if plan is None and not opts.urn:
                raise TypeError("Missing required property 'plan'")
            __props__.__dict__["plan"] = plan
            __props__.__dict__["service_name"] = service_name
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            __props__.__dict__["created_at"] = None
            __props__.__dict__["disk_type"] = None
            __props__.__dict__["endpoints"] = None
            __props__.__dict__["network_type"] = None
            __props__.__dict__["status"] = None
        super(Database, __self__).__init__(
            'ovh:CloudProject/database:Database',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            advanced_configuration: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            backup_regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            backup_time: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            disk_size: Optional[pulumi.Input[builtins.int]] = None,
            disk_type: Optional[pulumi.Input[builtins.str]] = None,
            endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseEndpointArgs', 'DatabaseEndpointArgsDict']]]]] = None,
            engine: Optional[pulumi.Input[builtins.str]] = None,
            flavor: Optional[pulumi.Input[builtins.str]] = None,
            ip_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseIpRestrictionArgs', 'DatabaseIpRestrictionArgsDict']]]]] = None,
            kafka_rest_api: Optional[pulumi.Input[builtins.bool]] = None,
            kafka_schema_registry: Optional[pulumi.Input[builtins.bool]] = None,
            maintenance_time: Optional[pulumi.Input[builtins.str]] = None,
            network_type: Optional[pulumi.Input[builtins.str]] = None,
            nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseNodeArgs', 'DatabaseNodeArgsDict']]]]] = None,
            opensearch_acls_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            plan: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None) -> 'Database':
        """
        Get an existing Database resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] advanced_configuration: Advanced configuration key / value.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] backup_regions: List of region where backups are pushed. Not more than 1 regions for MongoDB. Not more than 2 regions for the other engines with one being the same as the nodes[].region field
        :param pulumi.Input[builtins.str] backup_time: Time on which backups start every day (this parameter is not usable on the following engines: "m3db", "grafana", "kafka", "kafkaconnect", "kafkamirrormaker", "opensearch", "m3aggregator").
        :param pulumi.Input[builtins.str] created_at: Date of the creation of the cluster.
        :param pulumi.Input[builtins.str] description: Small description of the database service.
        :param pulumi.Input[builtins.int] disk_size: The disk size (in GB) of the database service.
        :param pulumi.Input[builtins.str] disk_type: Defines the disk type of the database service.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseEndpointArgs', 'DatabaseEndpointArgsDict']]]] endpoints: List of all endpoints objects of the service.
        :param pulumi.Input[builtins.str] engine: The database engine you want to deploy. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] flavor: A valid OVHcloud public cloud database flavor name in which the nodes will be started. Ex: "db1-7". Changing this value upgrade the nodes with the new flavor. You can find the list of flavor names: https://www.ovhcloud.com/fr/public-cloud/prices/
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseIpRestrictionArgs', 'DatabaseIpRestrictionArgsDict']]]] ip_restrictions: IP Blocks authorized to access to the cluster.
        :param pulumi.Input[builtins.bool] kafka_rest_api: Defines whether the REST API is enabled on a kafka cluster
        :param pulumi.Input[builtins.bool] kafka_schema_registry: Defines whether the schema registry is enabled on a Kafka cluster
        :param pulumi.Input[builtins.str] maintenance_time: Time on which maintenances can start every day.
        :param pulumi.Input[builtins.str] network_type: Type of network of the cluster.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseNodeArgs', 'DatabaseNodeArgsDict']]]] nodes: List of nodes object. Multi region cluster are not yet available, all node should be identical.
        :param pulumi.Input[builtins.bool] opensearch_acls_enabled: Defines whether the ACLs are enabled on an OpenSearch cluster
        :param pulumi.Input[builtins.str] plan: Plan of the cluster.
               * MongoDB: Enum: "discovery", "production", "advanced".
               * Mysql, PosgreSQL, Cassandra, M3DB, : Enum: "essential", "business", "enterprise".
               * M3 Aggregator: "business", "enterprise".
               * Redis: "essential", "business".
               * Valkey: "essential", "business".
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: Current status of the cluster.
        :param pulumi.Input[builtins.str] version: The version of the engine in which the service should be deployed
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseState.__new__(_DatabaseState)

        __props__.__dict__["advanced_configuration"] = advanced_configuration
        __props__.__dict__["backup_regions"] = backup_regions
        __props__.__dict__["backup_time"] = backup_time
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["disk_size"] = disk_size
        __props__.__dict__["disk_type"] = disk_type
        __props__.__dict__["endpoints"] = endpoints
        __props__.__dict__["engine"] = engine
        __props__.__dict__["flavor"] = flavor
        __props__.__dict__["ip_restrictions"] = ip_restrictions
        __props__.__dict__["kafka_rest_api"] = kafka_rest_api
        __props__.__dict__["kafka_schema_registry"] = kafka_schema_registry
        __props__.__dict__["maintenance_time"] = maintenance_time
        __props__.__dict__["network_type"] = network_type
        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["opensearch_acls_enabled"] = opensearch_acls_enabled
        __props__.__dict__["plan"] = plan
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["version"] = version
        return Database(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="advancedConfiguration")
    def advanced_configuration(self) -> pulumi.Output[Mapping[str, builtins.str]]:
        """
        Advanced configuration key / value.
        """
        return pulumi.get(self, "advanced_configuration")

    @property
    @pulumi.getter(name="backupRegions")
    def backup_regions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of region where backups are pushed. Not more than 1 regions for MongoDB. Not more than 2 regions for the other engines with one being the same as the nodes[].region field
        """
        return pulumi.get(self, "backup_regions")

    @property
    @pulumi.getter(name="backupTime")
    def backup_time(self) -> pulumi.Output[builtins.str]:
        """
        Time on which backups start every day (this parameter is not usable on the following engines: "m3db", "grafana", "kafka", "kafkaconnect", "kafkamirrormaker", "opensearch", "m3aggregator").
        """
        return pulumi.get(self, "backup_time")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Date of the creation of the cluster.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Small description of the database service.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> pulumi.Output[builtins.int]:
        """
        The disk size (in GB) of the database service.
        """
        return pulumi.get(self, "disk_size")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> pulumi.Output[builtins.str]:
        """
        Defines the disk type of the database service.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter
    def endpoints(self) -> pulumi.Output[Sequence['outputs.DatabaseEndpoint']]:
        """
        List of all endpoints objects of the service.
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Output[builtins.str]:
        """
        The database engine you want to deploy. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter
    def flavor(self) -> pulumi.Output[builtins.str]:
        """
        A valid OVHcloud public cloud database flavor name in which the nodes will be started. Ex: "db1-7". Changing this value upgrade the nodes with the new flavor. You can find the list of flavor names: https://www.ovhcloud.com/fr/public-cloud/prices/
        """
        return pulumi.get(self, "flavor")

    @property
    @pulumi.getter(name="ipRestrictions")
    def ip_restrictions(self) -> pulumi.Output[Optional[Sequence['outputs.DatabaseIpRestriction']]]:
        """
        IP Blocks authorized to access to the cluster.
        """
        return pulumi.get(self, "ip_restrictions")

    @property
    @pulumi.getter(name="kafkaRestApi")
    def kafka_rest_api(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Defines whether the REST API is enabled on a kafka cluster
        """
        return pulumi.get(self, "kafka_rest_api")

    @property
    @pulumi.getter(name="kafkaSchemaRegistry")
    def kafka_schema_registry(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Defines whether the schema registry is enabled on a Kafka cluster
        """
        return pulumi.get(self, "kafka_schema_registry")

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> pulumi.Output[builtins.str]:
        """
        Time on which maintenances can start every day.
        """
        return pulumi.get(self, "maintenance_time")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> pulumi.Output[builtins.str]:
        """
        Type of network of the cluster.
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[Sequence['outputs.DatabaseNode']]:
        """
        List of nodes object. Multi region cluster are not yet available, all node should be identical.
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter(name="opensearchAclsEnabled")
    def opensearch_acls_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Defines whether the ACLs are enabled on an OpenSearch cluster
        """
        return pulumi.get(self, "opensearch_acls_enabled")

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Output[builtins.str]:
        """
        Plan of the cluster.
        * MongoDB: Enum: "discovery", "production", "advanced".
        * Mysql, PosgreSQL, Cassandra, M3DB, : Enum: "essential", "business", "enterprise".
        * M3 Aggregator: "business", "enterprise".
        * Redis: "essential", "business".
        * Valkey: "essential", "business".
        """
        return pulumi.get(self, "plan")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Current status of the cluster.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.str]:
        """
        The version of the engine in which the service should be deployed
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VrackNetworkArgs', 'VrackNetwork']

@pulumi.input_type
class VrackNetworkArgs:
    def __init__(__self__, *,
                 nat_ip: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 subnet: pulumi.Input[builtins.str],
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 farm_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 vlan: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a VrackNetwork resource.
        :param pulumi.Input[builtins.str] nat_ip: An IP block used as a pool of IPs by this Load Balancer to connect to the servers in this private network. The blck must be in the private network and reserved for the Load Balancer
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] subnet: IP block of the private network in the vRack
        :param pulumi.Input[builtins.str] display_name: Human readable name for your vrack network
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] farm_ids: This attribute is there for documentation purpose only and isnt passed to the OVHcloud API as it may conflicts with http/tcp farms `vrack_network_id` attribute
        :param pulumi.Input[builtins.int] vlan: VLAN of the private network in the vRack. 0 if the private network is not in a VLAN
        """
        pulumi.set(__self__, "nat_ip", nat_ip)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "subnet", subnet)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if farm_ids is not None:
            pulumi.set(__self__, "farm_ids", farm_ids)
        if vlan is not None:
            pulumi.set(__self__, "vlan", vlan)

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> pulumi.Input[builtins.str]:
        """
        An IP block used as a pool of IPs by this Load Balancer to connect to the servers in this private network. The blck must be in the private network and reserved for the Load Balancer
        """
        return pulumi.get(self, "nat_ip")

    @nat_ip.setter
    def nat_ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nat_ip", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def subnet(self) -> pulumi.Input[builtins.str]:
        """
        IP block of the private network in the vRack
        """
        return pulumi.get(self, "subnet")

    @subnet.setter
    def subnet(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human readable name for your vrack network
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="farmIds")
    def farm_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        This attribute is there for documentation purpose only and isnt passed to the OVHcloud API as it may conflicts with http/tcp farms `vrack_network_id` attribute
        """
        return pulumi.get(self, "farm_ids")

    @farm_ids.setter
    def farm_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "farm_ids", value)

    @property
    @pulumi.getter
    def vlan(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VLAN of the private network in the vRack. 0 if the private network is not in a VLAN
        """
        return pulumi.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vlan", value)


@pulumi.input_type
class _VrackNetworkState:
    def __init__(__self__, *,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 farm_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 vlan: Optional[pulumi.Input[builtins.int]] = None,
                 vrack_network_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering VrackNetwork resources.
        :param pulumi.Input[builtins.str] display_name: Human readable name for your vrack network
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] farm_ids: This attribute is there for documentation purpose only and isnt passed to the OVHcloud API as it may conflicts with http/tcp farms `vrack_network_id` attribute
        :param pulumi.Input[builtins.str] nat_ip: An IP block used as a pool of IPs by this Load Balancer to connect to the servers in this private network. The blck must be in the private network and reserved for the Load Balancer
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] subnet: IP block of the private network in the vRack
        :param pulumi.Input[builtins.int] vlan: VLAN of the private network in the vRack. 0 if the private network is not in a VLAN
        :param pulumi.Input[builtins.int] vrack_network_id: (Required) Internal Load Balancer identifier of the vRack private network
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if farm_ids is not None:
            pulumi.set(__self__, "farm_ids", farm_ids)
        if nat_ip is not None:
            pulumi.set(__self__, "nat_ip", nat_ip)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if subnet is not None:
            pulumi.set(__self__, "subnet", subnet)
        if vlan is not None:
            pulumi.set(__self__, "vlan", vlan)
        if vrack_network_id is not None:
            pulumi.set(__self__, "vrack_network_id", vrack_network_id)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human readable name for your vrack network
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="farmIds")
    def farm_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        This attribute is there for documentation purpose only and isnt passed to the OVHcloud API as it may conflicts with http/tcp farms `vrack_network_id` attribute
        """
        return pulumi.get(self, "farm_ids")

    @farm_ids.setter
    def farm_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "farm_ids", value)

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An IP block used as a pool of IPs by this Load Balancer to connect to the servers in this private network. The blck must be in the private network and reserved for the Load Balancer
        """
        return pulumi.get(self, "nat_ip")

    @nat_ip.setter
    def nat_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def subnet(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP block of the private network in the vRack
        """
        return pulumi.get(self, "subnet")

    @subnet.setter
    def subnet(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet", value)

    @property
    @pulumi.getter
    def vlan(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VLAN of the private network in the vRack. 0 if the private network is not in a VLAN
        """
        return pulumi.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vlan", value)

    @property
    @pulumi.getter(name="vrackNetworkId")
    def vrack_network_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        (Required) Internal Load Balancer identifier of the vRack private network
        """
        return pulumi.get(self, "vrack_network_id")

    @vrack_network_id.setter
    def vrack_network_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vrack_network_id", value)


@pulumi.type_token("ovh:IpLoadBalancing/vrackNetwork:VrackNetwork")
class VrackNetwork(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 farm_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 vlan: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Manage a vrack network for your IP Loadbalancing service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        iplb = ovh.IpLoadBalancing.get_ip_load_balancing(service_name="loadbalancer-xxxxxxxxxxxxxxxxxx")
        vip_lb = ovh.vrack.IpLoadbalancing("vip_lb",
            service_name="xxx",
            loadbalancing_id=iplb.service_name)
        network = ovh.ip_load_balancing.VrackNetwork("network",
            service_name=vip_lb.loadbalancing_id,
            subnet="10.0.0.0/16",
            vlan=1,
            nat_ip="10.0.0.0/27",
            display_name="mynetwork")
        test_farm = ovh.ip_load_balancing.TcpFarm("test_farm",
            service_name=network.service_name,
            display_name="mytcpbackends",
            port=80,
            vrack_network_id=network.vrack_network_id,
            zone=iplb.zones[0])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] display_name: Human readable name for your vrack network
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] farm_ids: This attribute is there for documentation purpose only and isnt passed to the OVHcloud API as it may conflicts with http/tcp farms `vrack_network_id` attribute
        :param pulumi.Input[builtins.str] nat_ip: An IP block used as a pool of IPs by this Load Balancer to connect to the servers in this private network. The blck must be in the private network and reserved for the Load Balancer
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] subnet: IP block of the private network in the vRack
        :param pulumi.Input[builtins.int] vlan: VLAN of the private network in the vRack. 0 if the private network is not in a VLAN
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VrackNetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage a vrack network for your IP Loadbalancing service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        iplb = ovh.IpLoadBalancing.get_ip_load_balancing(service_name="loadbalancer-xxxxxxxxxxxxxxxxxx")
        vip_lb = ovh.vrack.IpLoadbalancing("vip_lb",
            service_name="xxx",
            loadbalancing_id=iplb.service_name)
        network = ovh.ip_load_balancing.VrackNetwork("network",
            service_name=vip_lb.loadbalancing_id,
            subnet="10.0.0.0/16",
            vlan=1,
            nat_ip="10.0.0.0/27",
            display_name="mynetwork")
        test_farm = ovh.ip_load_balancing.TcpFarm("test_farm",
            service_name=network.service_name,
            display_name="mytcpbackends",
            port=80,
            vrack_network_id=network.vrack_network_id,
            zone=iplb.zones[0])
        ```

        :param str resource_name: The name of the resource.
        :param VrackNetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VrackNetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 farm_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 vlan: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VrackNetworkArgs.__new__(VrackNetworkArgs)

            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["farm_ids"] = farm_ids
            if nat_ip is None and not opts.urn:
                raise TypeError("Missing required property 'nat_ip'")
            __props__.__dict__["nat_ip"] = nat_ip
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if subnet is None and not opts.urn:
                raise TypeError("Missing required property 'subnet'")
            __props__.__dict__["subnet"] = subnet
            __props__.__dict__["vlan"] = vlan
            __props__.__dict__["vrack_network_id"] = None
        super(VrackNetwork, __self__).__init__(
            'ovh:IpLoadBalancing/vrackNetwork:VrackNetwork',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            farm_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
            nat_ip: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            subnet: Optional[pulumi.Input[builtins.str]] = None,
            vlan: Optional[pulumi.Input[builtins.int]] = None,
            vrack_network_id: Optional[pulumi.Input[builtins.int]] = None) -> 'VrackNetwork':
        """
        Get an existing VrackNetwork resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] display_name: Human readable name for your vrack network
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] farm_ids: This attribute is there for documentation purpose only and isnt passed to the OVHcloud API as it may conflicts with http/tcp farms `vrack_network_id` attribute
        :param pulumi.Input[builtins.str] nat_ip: An IP block used as a pool of IPs by this Load Balancer to connect to the servers in this private network. The blck must be in the private network and reserved for the Load Balancer
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] subnet: IP block of the private network in the vRack
        :param pulumi.Input[builtins.int] vlan: VLAN of the private network in the vRack. 0 if the private network is not in a VLAN
        :param pulumi.Input[builtins.int] vrack_network_id: (Required) Internal Load Balancer identifier of the vRack private network
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VrackNetworkState.__new__(_VrackNetworkState)

        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["farm_ids"] = farm_ids
        __props__.__dict__["nat_ip"] = nat_ip
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["subnet"] = subnet
        __props__.__dict__["vlan"] = vlan
        __props__.__dict__["vrack_network_id"] = vrack_network_id
        return VrackNetwork(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Human readable name for your vrack network
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="farmIds")
    def farm_ids(self) -> pulumi.Output[Optional[Sequence[builtins.int]]]:
        """
        This attribute is there for documentation purpose only and isnt passed to the OVHcloud API as it may conflicts with http/tcp farms `vrack_network_id` attribute
        """
        return pulumi.get(self, "farm_ids")

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> pulumi.Output[builtins.str]:
        """
        An IP block used as a pool of IPs by this Load Balancer to connect to the servers in this private network. The blck must be in the private network and reserved for the Load Balancer
        """
        return pulumi.get(self, "nat_ip")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def subnet(self) -> pulumi.Output[builtins.str]:
        """
        IP block of the private network in the vRack
        """
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter
    def vlan(self) -> pulumi.Output[builtins.int]:
        """
        VLAN of the private network in the vRack. 0 if the private network is not in a VLAN
        """
        return pulumi.get(self, "vlan")

    @property
    @pulumi.getter(name="vrackNetworkId")
    def vrack_network_id(self) -> pulumi.Output[builtins.int]:
        """
        (Required) Internal Load Balancer identifier of the vRack private network
        """
        return pulumi.get(self, "vrack_network_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetLogsOutputGraylogStreamResult',
    'AwaitableGetLogsOutputGraylogStreamResult',
    'get_logs_output_graylog_stream',
    'get_logs_output_graylog_stream_output',
]

@pulumi.output_type
class GetLogsOutputGraylogStreamResult:
    """
    A collection of values returned by getLogsOutputGraylogStream.
    """
    def __init__(__self__, can_alert=None, cold_storage_compression=None, cold_storage_content=None, cold_storage_enabled=None, cold_storage_notify_enabled=None, cold_storage_retention=None, cold_storage_target=None, created_at=None, description=None, id=None, indexing_enabled=None, indexing_max_size=None, indexing_notify_enabled=None, is_editable=None, is_shareable=None, nb_alert_condition=None, nb_archive=None, parent_stream_id=None, pause_indexing_on_max_size=None, retention_id=None, service_name=None, stream_id=None, title=None, updated_at=None, web_socket_enabled=None, write_token=None):
        if can_alert and not isinstance(can_alert, bool):
            raise TypeError("Expected argument 'can_alert' to be a bool")
        pulumi.set(__self__, "can_alert", can_alert)
        if cold_storage_compression and not isinstance(cold_storage_compression, str):
            raise TypeError("Expected argument 'cold_storage_compression' to be a str")
        pulumi.set(__self__, "cold_storage_compression", cold_storage_compression)
        if cold_storage_content and not isinstance(cold_storage_content, str):
            raise TypeError("Expected argument 'cold_storage_content' to be a str")
        pulumi.set(__self__, "cold_storage_content", cold_storage_content)
        if cold_storage_enabled and not isinstance(cold_storage_enabled, bool):
            raise TypeError("Expected argument 'cold_storage_enabled' to be a bool")
        pulumi.set(__self__, "cold_storage_enabled", cold_storage_enabled)
        if cold_storage_notify_enabled and not isinstance(cold_storage_notify_enabled, bool):
            raise TypeError("Expected argument 'cold_storage_notify_enabled' to be a bool")
        pulumi.set(__self__, "cold_storage_notify_enabled", cold_storage_notify_enabled)
        if cold_storage_retention and not isinstance(cold_storage_retention, int):
            raise TypeError("Expected argument 'cold_storage_retention' to be a int")
        pulumi.set(__self__, "cold_storage_retention", cold_storage_retention)
        if cold_storage_target and not isinstance(cold_storage_target, str):
            raise TypeError("Expected argument 'cold_storage_target' to be a str")
        pulumi.set(__self__, "cold_storage_target", cold_storage_target)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if indexing_enabled and not isinstance(indexing_enabled, bool):
            raise TypeError("Expected argument 'indexing_enabled' to be a bool")
        pulumi.set(__self__, "indexing_enabled", indexing_enabled)
        if indexing_max_size and not isinstance(indexing_max_size, int):
            raise TypeError("Expected argument 'indexing_max_size' to be a int")
        pulumi.set(__self__, "indexing_max_size", indexing_max_size)
        if indexing_notify_enabled and not isinstance(indexing_notify_enabled, bool):
            raise TypeError("Expected argument 'indexing_notify_enabled' to be a bool")
        pulumi.set(__self__, "indexing_notify_enabled", indexing_notify_enabled)
        if is_editable and not isinstance(is_editable, bool):
            raise TypeError("Expected argument 'is_editable' to be a bool")
        pulumi.set(__self__, "is_editable", is_editable)
        if is_shareable and not isinstance(is_shareable, bool):
            raise TypeError("Expected argument 'is_shareable' to be a bool")
        pulumi.set(__self__, "is_shareable", is_shareable)
        if nb_alert_condition and not isinstance(nb_alert_condition, int):
            raise TypeError("Expected argument 'nb_alert_condition' to be a int")
        pulumi.set(__self__, "nb_alert_condition", nb_alert_condition)
        if nb_archive and not isinstance(nb_archive, int):
            raise TypeError("Expected argument 'nb_archive' to be a int")
        pulumi.set(__self__, "nb_archive", nb_archive)
        if parent_stream_id and not isinstance(parent_stream_id, str):
            raise TypeError("Expected argument 'parent_stream_id' to be a str")
        pulumi.set(__self__, "parent_stream_id", parent_stream_id)
        if pause_indexing_on_max_size and not isinstance(pause_indexing_on_max_size, bool):
            raise TypeError("Expected argument 'pause_indexing_on_max_size' to be a bool")
        pulumi.set(__self__, "pause_indexing_on_max_size", pause_indexing_on_max_size)
        if retention_id and not isinstance(retention_id, str):
            raise TypeError("Expected argument 'retention_id' to be a str")
        pulumi.set(__self__, "retention_id", retention_id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if stream_id and not isinstance(stream_id, str):
            raise TypeError("Expected argument 'stream_id' to be a str")
        pulumi.set(__self__, "stream_id", stream_id)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if web_socket_enabled and not isinstance(web_socket_enabled, bool):
            raise TypeError("Expected argument 'web_socket_enabled' to be a bool")
        pulumi.set(__self__, "web_socket_enabled", web_socket_enabled)
        if write_token and not isinstance(write_token, str):
            raise TypeError("Expected argument 'write_token' to be a str")
        pulumi.set(__self__, "write_token", write_token)

    @property
    @pulumi.getter(name="canAlert")
    def can_alert(self) -> builtins.bool:
        return pulumi.get(self, "can_alert")

    @property
    @pulumi.getter(name="coldStorageCompression")
    def cold_storage_compression(self) -> builtins.str:
        """
        Cold storage compression method
        """
        return pulumi.get(self, "cold_storage_compression")

    @property
    @pulumi.getter(name="coldStorageContent")
    def cold_storage_content(self) -> builtins.str:
        """
        ColdStorage content
        """
        return pulumi.get(self, "cold_storage_content")

    @property
    @pulumi.getter(name="coldStorageEnabled")
    def cold_storage_enabled(self) -> builtins.bool:
        """
        Is Cold storage enabled?
        """
        return pulumi.get(self, "cold_storage_enabled")

    @property
    @pulumi.getter(name="coldStorageNotifyEnabled")
    def cold_storage_notify_enabled(self) -> builtins.bool:
        """
        Notify on new Cold storage archive
        """
        return pulumi.get(self, "cold_storage_notify_enabled")

    @property
    @pulumi.getter(name="coldStorageRetention")
    def cold_storage_retention(self) -> builtins.int:
        """
        Cold storage retention in year
        """
        return pulumi.get(self, "cold_storage_retention")

    @property
    @pulumi.getter(name="coldStorageTarget")
    def cold_storage_target(self) -> builtins.str:
        """
        ColdStorage destination
        """
        return pulumi.get(self, "cold_storage_target")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        Stream creation
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Stream description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="indexingEnabled")
    def indexing_enabled(self) -> builtins.bool:
        """
        Enable ES indexing
        """
        return pulumi.get(self, "indexing_enabled")

    @property
    @pulumi.getter(name="indexingMaxSize")
    def indexing_max_size(self) -> builtins.int:
        """
        Maximum indexing size (in GB)
        """
        return pulumi.get(self, "indexing_max_size")

    @property
    @pulumi.getter(name="indexingNotifyEnabled")
    def indexing_notify_enabled(self) -> builtins.bool:
        """
        If set, notify when size is near 80, 90 or 100 % of the maximum configured setting
        """
        return pulumi.get(self, "indexing_notify_enabled")

    @property
    @pulumi.getter(name="isEditable")
    def is_editable(self) -> builtins.bool:
        """
        Indicates if you are allowed to edit entry
        """
        return pulumi.get(self, "is_editable")

    @property
    @pulumi.getter(name="isShareable")
    def is_shareable(self) -> builtins.bool:
        """
        Indicates if you are allowed to share entry
        """
        return pulumi.get(self, "is_shareable")

    @property
    @pulumi.getter(name="nbAlertCondition")
    def nb_alert_condition(self) -> builtins.int:
        """
        Number of alert condition
        """
        return pulumi.get(self, "nb_alert_condition")

    @property
    @pulumi.getter(name="nbArchive")
    def nb_archive(self) -> builtins.int:
        """
        Number of coldstored archives
        """
        return pulumi.get(self, "nb_archive")

    @property
    @pulumi.getter(name="parentStreamId")
    def parent_stream_id(self) -> builtins.str:
        """
        Parent stream ID
        """
        return pulumi.get(self, "parent_stream_id")

    @property
    @pulumi.getter(name="pauseIndexingOnMaxSize")
    def pause_indexing_on_max_size(self) -> builtins.bool:
        """
        If set, pause indexing when maximum size is reach
        """
        return pulumi.get(self, "pause_indexing_on_max_size")

    @property
    @pulumi.getter(name="retentionId")
    def retention_id(self) -> builtins.str:
        """
        Retention ID
        """
        return pulumi.get(self, "retention_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> builtins.str:
        """
        Stream ID
        """
        return pulumi.get(self, "stream_id")

    @property
    @pulumi.getter
    def title(self) -> builtins.str:
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        Stream last update
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="webSocketEnabled")
    def web_socket_enabled(self) -> builtins.bool:
        """
        Enable Websocket
        """
        return pulumi.get(self, "web_socket_enabled")

    @property
    @pulumi.getter(name="writeToken")
    def write_token(self) -> builtins.str:
        """
        Write token of the stream (empty if the caller is not the owner of the stream)
        """
        return pulumi.get(self, "write_token")


class AwaitableGetLogsOutputGraylogStreamResult(GetLogsOutputGraylogStreamResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLogsOutputGraylogStreamResult(
            can_alert=self.can_alert,
            cold_storage_compression=self.cold_storage_compression,
            cold_storage_content=self.cold_storage_content,
            cold_storage_enabled=self.cold_storage_enabled,
            cold_storage_notify_enabled=self.cold_storage_notify_enabled,
            cold_storage_retention=self.cold_storage_retention,
            cold_storage_target=self.cold_storage_target,
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            indexing_enabled=self.indexing_enabled,
            indexing_max_size=self.indexing_max_size,
            indexing_notify_enabled=self.indexing_notify_enabled,
            is_editable=self.is_editable,
            is_shareable=self.is_shareable,
            nb_alert_condition=self.nb_alert_condition,
            nb_archive=self.nb_archive,
            parent_stream_id=self.parent_stream_id,
            pause_indexing_on_max_size=self.pause_indexing_on_max_size,
            retention_id=self.retention_id,
            service_name=self.service_name,
            stream_id=self.stream_id,
            title=self.title,
            updated_at=self.updated_at,
            web_socket_enabled=self.web_socket_enabled,
            write_token=self.write_token)


def get_logs_output_graylog_stream(service_name: Optional[builtins.str] = None,
                                   title: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLogsOutputGraylogStreamResult:
    """
    Use this data source to retrieve information about a DBaas logs output graylog stream.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    stream = ovh.Dbaas.get_logs_output_graylog_stream(service_name="ldp-xx-xxxxx",
        title="my stream")
    ```


    :param builtins.str service_name: The service name. It's the ID of your Logs Data Platform instance.
    :param builtins.str title: Stream description
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['title'] = title
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Dbaas/getLogsOutputGraylogStream:getLogsOutputGraylogStream', __args__, opts=opts, typ=GetLogsOutputGraylogStreamResult).value

    return AwaitableGetLogsOutputGraylogStreamResult(
        can_alert=pulumi.get(__ret__, 'can_alert'),
        cold_storage_compression=pulumi.get(__ret__, 'cold_storage_compression'),
        cold_storage_content=pulumi.get(__ret__, 'cold_storage_content'),
        cold_storage_enabled=pulumi.get(__ret__, 'cold_storage_enabled'),
        cold_storage_notify_enabled=pulumi.get(__ret__, 'cold_storage_notify_enabled'),
        cold_storage_retention=pulumi.get(__ret__, 'cold_storage_retention'),
        cold_storage_target=pulumi.get(__ret__, 'cold_storage_target'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        indexing_enabled=pulumi.get(__ret__, 'indexing_enabled'),
        indexing_max_size=pulumi.get(__ret__, 'indexing_max_size'),
        indexing_notify_enabled=pulumi.get(__ret__, 'indexing_notify_enabled'),
        is_editable=pulumi.get(__ret__, 'is_editable'),
        is_shareable=pulumi.get(__ret__, 'is_shareable'),
        nb_alert_condition=pulumi.get(__ret__, 'nb_alert_condition'),
        nb_archive=pulumi.get(__ret__, 'nb_archive'),
        parent_stream_id=pulumi.get(__ret__, 'parent_stream_id'),
        pause_indexing_on_max_size=pulumi.get(__ret__, 'pause_indexing_on_max_size'),
        retention_id=pulumi.get(__ret__, 'retention_id'),
        service_name=pulumi.get(__ret__, 'service_name'),
        stream_id=pulumi.get(__ret__, 'stream_id'),
        title=pulumi.get(__ret__, 'title'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        web_socket_enabled=pulumi.get(__ret__, 'web_socket_enabled'),
        write_token=pulumi.get(__ret__, 'write_token'))
def get_logs_output_graylog_stream_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                                          title: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLogsOutputGraylogStreamResult]:
    """
    Use this data source to retrieve information about a DBaas logs output graylog stream.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    stream = ovh.Dbaas.get_logs_output_graylog_stream(service_name="ldp-xx-xxxxx",
        title="my stream")
    ```


    :param builtins.str service_name: The service name. It's the ID of your Logs Data Platform instance.
    :param builtins.str title: Stream description
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['title'] = title
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Dbaas/getLogsOutputGraylogStream:getLogsOutputGraylogStream', __args__, opts=opts, typ=GetLogsOutputGraylogStreamResult)
    return __ret__.apply(lambda __response__: GetLogsOutputGraylogStreamResult(
        can_alert=pulumi.get(__response__, 'can_alert'),
        cold_storage_compression=pulumi.get(__response__, 'cold_storage_compression'),
        cold_storage_content=pulumi.get(__response__, 'cold_storage_content'),
        cold_storage_enabled=pulumi.get(__response__, 'cold_storage_enabled'),
        cold_storage_notify_enabled=pulumi.get(__response__, 'cold_storage_notify_enabled'),
        cold_storage_retention=pulumi.get(__response__, 'cold_storage_retention'),
        cold_storage_target=pulumi.get(__response__, 'cold_storage_target'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        indexing_enabled=pulumi.get(__response__, 'indexing_enabled'),
        indexing_max_size=pulumi.get(__response__, 'indexing_max_size'),
        indexing_notify_enabled=pulumi.get(__response__, 'indexing_notify_enabled'),
        is_editable=pulumi.get(__response__, 'is_editable'),
        is_shareable=pulumi.get(__response__, 'is_shareable'),
        nb_alert_condition=pulumi.get(__response__, 'nb_alert_condition'),
        nb_archive=pulumi.get(__response__, 'nb_archive'),
        parent_stream_id=pulumi.get(__response__, 'parent_stream_id'),
        pause_indexing_on_max_size=pulumi.get(__response__, 'pause_indexing_on_max_size'),
        retention_id=pulumi.get(__response__, 'retention_id'),
        service_name=pulumi.get(__response__, 'service_name'),
        stream_id=pulumi.get(__response__, 'stream_id'),
        title=pulumi.get(__response__, 'title'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        web_socket_enabled=pulumi.get(__response__, 'web_socket_enabled'),
        write_token=pulumi.get(__response__, 'write_token')))
